<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ml">
<context>
    <name>LockScreen</name>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="202"/>
        <source>Password</source>
        <translation>പാസ്സ്‌വേർഡ്</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="225"/>
        <source>Unlock</source>
        <translation>അൺലോക്ക്</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="274"/>
        <source>Please enter your password</source>
        <translation>നിങ്ങളുടെ പാസ്സ്‌വേർഡ് ടൈപ്പ് ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="284"/>
        <source>Unlocking failed</source>
        <translation>അൺലോക്ക് ചെയ്യാൻ കഴിഞ്ഞില്ല</translation>
    </message>
</context>
</TS>
